==> haskell-httpd-shed-0.4.1.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.1.0
id: httpd-shed-0.4.1.0-FwYTXLSAEB42vLOF7vAcMl
key: httpd-shed-0.4.1.0-FwYTXLSAEB42vLOF7vAcMl
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Ganesh Sittampalam
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: 1aac5b9f3eb9209fee54088d4d871f9c
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.6.4/site-local/httpd-shed-0.4.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/httpd-shed-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/httpd-shed-0.4.1.0
hs-libraries: HShttpd-shed-0.4.1.0-FwYTXLSAEB42vLOF7vAcMl
depends:
    base-4.12.0.0 network-2.8.0.0-58b93NZ1Nmb3T9F5Ys3Y7W
    network-bsd-2.8.0.0-H3SWYCM1m7m5QYx4i3TOG7
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.1.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.1.0
id: httpd-shed-0.4.1.0-HgATng22GpE39PGiUtRrD
key: httpd-shed-0.4.1.0-HgATng22GpE39PGiUtRrD
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Ganesh Sittampalam
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: 2ff33b376d277776f1a0598d19d31bb4
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.6.4/site-local/httpd-shed-0.4.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/httpd-shed-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/httpd-shed-0.4.1.0
hs-libraries: HShttpd-shed-0.4.1.0-HgATng22GpE39PGiUtRrD
depends:
    base-4.12.0.0 network-2.8.0.0-hUam69aq4P3U7qXHv1HmT
    network-bsd-2.8.0.0-2hWpwOUErawAVgtIBdlSKq
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
